@@ -4,10 +4,10 @@ from pathlib import Path
 from shlex import quote as Q
 import shutil
 
-from typing import Optional
+from typing import Union
 from subprocess import CalledProcessError
 
-async def run_subprocess(cmd: str, capture: Optional[bool], **kwargs) -> asyncio.subprocess.Process:
+async def run_subprocess(cmd: str, capture: Union[bool, str, None], **kwargs) -> Union[asyncio.subprocess.Process, str]:
     dest = asyncio.subprocess.PIPE if capture else None
     s = await create_subprocess_shell(cmd, stdout=dest, stderr=dest, executable=__.shell, cwd=__.cwd, **kwargs)
     await s.wait()
@@ -16,6 +16,10 @@ async def run_subprocess(cmd: str, capture: Optional[bool], **kwargs) -> asyncio
         s.stderr = (await s.stderr.read()).decode()
     if s.returncode:
         raise CalledProcessError(s.returncode, cmd, s.stdout, s.stderr)
+    if capture == 'o':
+        return s.stdout
+    elif capture == 'e':
+        return s.stderr
     return s
 
 def _deft(l, g):
@@ -27,10 +31,7 @@ def SHX(cmd: str, prefix=None, trace=None, capture=None, **kwargs):
     cmd = _deft(prefix, __.prefix) + cmd
     return run_subprocess(cmd, _deft(capture, __.capture), **kwargs)
 
-try:
-    from aiocontextvars import ContextVar
-except ModuleNotFoundError:
-    from contextvars import ContextVar
+from contextvars import ContextVar
 from sys import argv
 from os import environ
 class ROVar:
@@ -92,15 +93,38 @@ def _cmdstmt(s: str) -> str:
         result.append((toknum, tokval))
     return untokenize(result).decode('utf-8')
 
+def normalize_traceback(tb, srcname):
+    import types
+    if tb is None:
+        return
+    lineno = tb.tb_lineno - (tb.tb_frame.f_code.co_filename == srcname)
+    return types.TracebackType(normalize_traceback(tb.tb_next, srcname), tb.tb_frame, tb.tb_lasti, lineno)
+
 def main():
-    snippet = Path(argv[1]).read_text()
+    import sys
+    import ast
+    import types
+    srcname = argv[1]
+    snippet = Path(srcname).read_text()
     snippet = _cmdstmt(snippet)
-    async def amain(snippet):
-        exec(
-            'async def __ex(): ' +
-            ''.join(f'\n {l}' for l in snippet.split('\n'))
-        )
-        await locals()['__ex']()
-    run(amain(snippet))
+    if sys.version_info < (3, 8):
+        async def amain(snippet):
+            exec(compile(
+                'async def __shx_main(): ' + ''.join(f'\n {l}' for l in snippet.split('\n')),
+                srcname, 'exec'))
+            await locals()['__shx_main']()
+    else:
+        async def amain(snippet):
+            co = compile(snippet, srcname, 'exec', flags=ast.PyCF_ALLOW_TOP_LEVEL_AWAIT)
+            await types.FunctionType(co, globals())()
+    try:
+        run(amain(snippet))
+    except Exception:
+        import traceback
+        exc_type, exc_value, exc_traceback = sys.exc_info()
+        exc_traceback = exc_traceback.tb_next.tb_next.tb_next.tb_next
+        if sys.version_info < (3, 8):
+            exc_traceback = normalize_traceback(exc_traceback, srcname)
+        traceback.print_exception(exc_type, exc_value, exc_traceback, file=sys.stderr)
 if __name__ == "__main__":
     main()
